# easierexcel

## Excel

### Features

- log
- save
- open_excel
- open_file_input

## Sheet

### Features

- get_cell
- update_cell
- add_new_line
- delete_row
- delete_column
- format_header
- format_cell
- format_row
- format_all_cells
